CompositeIcon class abstract

Combines multiple icons into one.

Implemented types

Constructors

CompositeIcon()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

icon(String name) → Icon
Returns named Icon object that can be used to set icon and its style. Creates an empty Icon if it didn't exist.
isValid() → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → void
Removes the presentation. This method invalidates object.
inherited
removeAll() → void
Removes all layers.
removeIcon(String name) → void
Removes the named layer.
setIcon(ImageProvider image, IconStyle style, {required String name}) → void
Creates or resets a named layer with an icon and its style.
setIconStyle(IconStyle style, {required String name}) → void
Changes the icon style for a specific layer.
setIconWithCallback(ImageProvider image, IconStyle style, Callback onFinished, {required String name}) → void
Creates or resets a named layer that contains an icon and its style.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited