I18nManager class abstract

Localization manager.

Implemented types

Constructors

I18nManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
prefs ↔ I18nPrefs
Localization preferences.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
som ↔ SystemOfMeasurement
System of measurement used.
getter/setter pair
timeFormat ↔ TimeFormat
Preferred time format.
getter/setter pair

Methods

canonicalSpeed(double speed) → CanonicalUnit
Represents the speed with the value and unit of measurement separated.
isValid() → bool
localizeCanonicalUnit(CanonicalUnit canonicalUnit) → String
Localizes a value represented by canonical units.
localizeDataSize(int dataSize) → String
Converts data size to the current locale.
localizeDistance(int distance) → String
Converts a distance value to the current locale.
localizeDuration(int duration) → String
Converts a duration to the current locale.
localizeSpeed(double speed) → String
Converts speed to the current locale.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited