I18nPrefs class final

Localization preferences.

Available extensions

Constructors

I18nPrefs(SystemOfMeasurement som, TimeFormat timeFormat)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
som → SystemOfMeasurement
System of measurement (metric or imperial).
final
timeFormat → TimeFormat
Time format (12- or 24-hour).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant I18nPrefs other) → bool
The equality operator.
override